%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Technical Note TN167
% Parameters for 'Grid-Following Inverter (GFLI)'
% Copyright imperix ltd, 2024
% dev@imperix.ch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% SYSTEM PARAMETERS

SwitchingFreq = 50e3;           % Switching frequency [Hz]
ControlFreq = SwitchingFreq;    % Control frequency [Hz]
ControlPeriod = 1/ControlFreq;  % Control period [s]
SamplingPhase = 0.5;            % Sampling phase [-]

Vdc0 = 750;                     % Initial DC voltage [V]
Vg = 230;                       % RMS Grid voltage [V]
Freq = 50;                      % Grid frequency [Hz]
Lg = 0.95e-3;                   % TPI main inductor value [H]
Rg = 54e-3;                     % Series equivalent resistance of Lg [ohm]
Cdc = 1.5e-3;                   % DC bus capacitance [F]

%% GRID CURRENT CONTROLLER PARAMETERS (DQ)
% Magnitude optimum
K1 = 1/Rg;
T1 = Lg/Rg;
Td1 = (1/2 + 1/2 + 1/2)*ControlPeriod;
Tn1 = T1;
Ti1 = 2*K1*Td1;
KpIg = Tn1/Ti1;
KiIg = 1/Ti1;
